@@ -8,7 +8,8 @@ instances.
 from flask import current_app
 
 from ec2stack.providers import cloudstack
-from ec2stack.providers.cloudstack import requester, service_offerings, zones
+from ec2stack.providers.cloudstack import requester, service_offerings, zones, \
+    disk_offerings
 from ec2stack import helpers, errors
 
 
@@ -103,6 +104,48 @@ def _describe_instances_response(response):
     }
 
 
+@helpers.authentication_required
+def reboot_instance():
+    """
+    Reboot an instance.
+
+    @return: Response.
+    """
+    helpers.require_parameters(['InstanceId.1'])
+    instance_id = helpers.get('InstanceId.1')
+    _reboot_instance_request(instance_id)
+    return _reboot_instance_response()
+
+
+def _reboot_instance_request(instance_id):
+    """
+    Request to reboot an instance.
+
+    @param instance_id: Id of instance to be rebooted.
+    @return: Response.
+    """
+    args = {'command': 'rebootVirtualMachine',
+            'id': instance_id}
+    response = requester.make_request_async(args)
+    response = response['virtualmachine']
+    return response
+
+
+def _reboot_instance_response():
+    """
+    Generates a response for a reboot instance request.
+
+    @return: Response.
+    """
+    response = {
+        'template_name_or_list': 'status.xml',
+        'response_type': 'RebootInstancesResponse',
+        'return': 'true'
+    }
+
+    return response
+
+
 @helpers.authentication_required
 def run_instance():
     """
@@ -123,6 +166,26 @@ def _run_instance_request():
     @return: Response.
     """
     args = {}
+    if helpers.contains_parameter('Placement.AvailabilityZone'):
+        args['zoneid'] = zones.get_zone(
+            helpers.get('Placement.AvailabilityZone')
+        )
+    else:
+        args['zoneid'] = zones.get_zone(
+            current_app.config['CLOUDSTACK_DEFAULT_ZONE']
+        )['id']
+
+    if helpers.get('BlockDeviceMapping.1.Ebs.VolumeType') is not None:
+        disk_type = helpers.get('BlockDeviceMapping.1.Ebs.VolumeType')
+        if disk_type == 'gp2':
+            args['diskofferingid'] = disk_offerings.get_disk_offering(
+                current_app.config['CLOUDSTACK_CUSTOM_DISK_OFFERING']
+            )['id']
+
+        if helpers.get('BlockDeviceMapping.1.Ebs.VolumeSize') is None:
+            errors.invalid_request("VolumeSize not found in BlockDeviceMapping")
+        else:
+            args['size'] = helpers.get('BlockDeviceMapping.1.Ebs.VolumeSize')
 
     if helpers.get('InstanceType') is None:
         instance_type = 'm1.small'
@@ -139,15 +202,6 @@ def _run_instance_request():
         service_offerings.get_service_offering(instance_type)['id']
     args['templateid'] = helpers.get('ImageId')
 
-    if helpers.contains_parameter('Placement.AvailabilityZone'):
-        args['zoneid'] = zones.get_zone(
-            helpers.get('Placement.AvailabilityZone')
-        )
-    else:
-        args['zoneid'] = zones.get_zone(
-            current_app.config['CLOUDSTACK_DEFAULT_ZONE']
-        )['id']
-
     if helpers.contains_parameter('KeyName'):
         args['keypair'] = helpers.get('KeyName')
 
@@ -206,48 +260,6 @@ def _run_instance_response(response):
     return response
 
 
-@helpers.authentication_required
-def reboot_instance():
-    """
-    Reboot an instance.
-
-    @return: Response.
-    """
-    helpers.require_parameters(['InstanceId.1'])
-    instance_id = helpers.get('InstanceId.1')
-    _reboot_instance_request(instance_id)
-    return _reboot_instance_response()
-
-
-def _reboot_instance_request(instance_id):
-    """
-    Request to reboot an instance.
-
-    @param instance_id: Id of instance to be rebooted.
-    @return: Response.
-    """
-    args = {'command': 'rebootVirtualMachine',
-            'id': instance_id}
-    response = requester.make_request_async(args)
-    response = response['virtualmachine']
-    return response
-
-
-def _reboot_instance_response():
-    """
-    Generates a response for a reboot instance request.
-
-    @return: Response.
-    """
-    response = {
-        'template_name_or_list': 'status.xml',
-        'response_type': 'RebootInstancesResponse',
-        'return': 'true'
-    }
-
-    return response
-
-
 @helpers.authentication_required
 def start_instance():
     """
